from setuptools import setup, find_packages
setup(name='staros',
      version='1.0',
      description='Module for communicate with staros device',
      long_description='Connection to staros device, like Cisco ASR5700 or Cisco ASR5000',
      classifiers=[ 'Development Status :: 3 - Alpha',
                    'License :: OSI Approved :: MIT License',
                    'Programming Language :: Python :: 2.7',
                    'Topic :: Text Processing :: Linguistic', ],
      keywords='staros ASR ASR5700 ASR5000',
#      url='http://github.com/storborg/funniest',
      author='Dzmitry Buynovskiy',
      author_email='imperituro@mail.com',
      license='MIT',
      packages=find_packages(include=['staros'], exclude=['staros.tests']),
      install_requires=['paramiko', 'datetime'],
      include_package_data=True,
      zip_safe=False)
